@@ -25,6 +25,7 @@ LOCAL_DEPLOYMENT = os.getenv('LOCAL_DEPLOYMENT') # Optional
 
 def deploy(model_settings):
     failed_models = {}
+    base_path = os.getcwd()
     for setting in model_settings:
         try:
             (model_name, model_file, model_req_file, model_artifact_folder,
@@ -67,7 +68,6 @@ def deploy(model_settings):
                 to_deployment_folder(("akerbp.mlops.gc", "requirements.app"))
 
             logging.debug(f"cd {deployment_folder}")
-            base_path = os.getcwd()
             os.chdir(deployment_folder)
 
             logging.info("Write service settings file")
@@ -144,9 +144,8 @@ def deploy(model_settings):
                                     "End-to-end test skipped!")
         except Exception as error:
             error_type = type(error).__name__
-            error_message = f"Training service failed.\n{error_type}\n{error}"
+            error_message = f"Model failed to deploy!\n{error_type}\n{error}"
             logging.error(error_message)
-            logging.warning("Model failed to deploy!")
             failed_models[model_name] = error_message
 
         finally:
